(**************)
(* The Driver *)
open Printf
let usage_msg = "Usage: mscl [ -analyze ] input_file"

(* Command-line options and setters for Arg.parse *)
let analyze = ref false
let input_file = ref ""
let output_file = ref ""
let set_analyze ()   = analyze := true
let set_input_file f = input_file := f

(* Main *)
let main () =
  let desc =
    [("-analyze",   Arg.Unit(set_analyze),   "Semantic analysis and exit.")]
  in
  Arg.parse desc set_input_file usage_msg;
 
  if !input_file = "" then (print_endline usage_msg; exit 1);
  let dotindex=
  	try (String.rindex !input_file '.') with
  		|Not_found-> String.length !input_file
  		|_->String.rindex !input_file '.'
  in
  let inputName=String.sub !input_file 0 (dotindex) 
  in
  let output_file= inputName ^ ".java" 
  in

  (* Syntax *)
  let input = open_in !input_file in
  let lexbuf = Lexing.from_channel input in
  let program = Parser.program Scanner.token lexbuf in
  close_in input;
  
  (* Semantics *)
  ignore (Semantics.string_of_program program);
  if !analyze then exit 0;
  let oc=open_out output_file in
  let java = Javawriter.string_of_program program inputName in
  fprintf oc "%s" java;
  close_out oc;
  print_endline (output_file^" has been outputted.");
   exit 0 
  (* Run main *)
   let _ = try main () with Failure(s) -> (print_endline s; exit 1)